# Generated by Django 4.2.2 on 2023-06-21 16:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("hogwarts", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Article",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("title", models.CharField(max_length=255)),
                ("description", models.TextField()),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("beta", models.BooleanField(default=False)),
            ],
        ),
    ]
