
# test import


class MyFormView:
    pass


class MyListView:
    pass


class SomeAnotherClass:
    pass


class AnotherOne(SomeAnotherClass):
    pass


def post_view(request):
    pass


def confirm_post_view(request):
    pass


def get_view(request):
    pass


def just_function():
    pass
